===================
Octavia Contributor
===================

Contributor Guidelines
----------------------
.. toctree::
   :glob:
   :maxdepth: 1

   contributing.rst
   CONSTITUTION.rst
   HACKING.rst

Contributor Reference
---------------------
.. toctree::
   :glob:
   :maxdepth: 1

   guides/*
   devref/*


Internal APIs
-------------
.. toctree::
   :glob:
   :maxdepth: 1

   api/*

.. Note:: The documents listed below are design documents and specifications
          created and approved at a previous point in time. The code base and
          current functionality may deviate from these original documents.
          Please see the Octavia documentation for the current feature
          details.

Design Documentation
--------------------

Version 0.5 (liberty)
`````````````````````
.. toctree::
   :glob:
   :maxdepth: 1

   design/version0.5/*

Project Specifications
----------------------

Version 0.5 (liberty)
`````````````````````
.. toctree::
   :glob:
   :maxdepth: 1

   specs/version0.5/*

Version 0.8 (mitaka)
````````````````````
.. toctree::
   :glob:
   :maxdepth: 1

   specs/version0.8/*

Version 0.9 (newton)
````````````````````
.. toctree::
   :glob:
   :maxdepth: 1

   specs/version0.9/*

Version 1.0 (pike)
``````````````````
.. toctree::
   :glob:
   :maxdepth: 1

   specs/version1.0/*

Version 1.1 (queens)
````````````````````
.. toctree::
   :glob:
   :maxdepth: 1

   specs/version1.1/*


.. only:: latex

   Module Reference
   ----------------

   .. toctree::
      :hidden:

      modules/modules

.. only:: html

   Indices and Search
   ------------------

   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`
